@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import functools
 import json
 import logging
@@ -7,7 +9,7 @@ import socket
 import ssl
 import threading
 from asyncio.selector_events import BaseSelectorEventLoop
-from typing import Dict, List, Match, Optional, Union
+from typing import Dict, List, Match, Optional, Type, TypeVar, Union
 from urllib.parse import parse_qs, unquote, urlencode, urlparse
 
 import requests
@@ -32,6 +34,7 @@ from localstack.constants import (
     APPLICATION_JSON,
     AWS_REGION_US_EAST_1,
     BIND_HOST,
+    HEADER_LOCALSTACK_AUTHORIZATION,
     HEADER_LOCALSTACK_REQUEST_URL,
 )
 from localstack.services.messages import Headers, MessagePayload
@@ -49,7 +52,6 @@ from localstack.utils.server import http2_server
 from localstack.utils.serving import Server
 from localstack.utils.strings import to_bytes, to_str
 from localstack.utils.threads import start_thread
-from localstack.utils.urls import path_from_url
 
 # set up logger
 LOG = logging.getLogger(__name__)
@@ -111,12 +113,14 @@ ALLOWED_CORS_ORIGINS = [
     f"http://localhost.localstack.cloud:{config.EDGE_PORT}",
     "https://localhost",
     "https://localhost.localstack.cloud",
+    # for requests from Electron apps, e.g., DynamoDB NoSQL Workbench
+    "file://",
 ]
 if EXTRA_CORS_ALLOWED_ORIGINS:
     ALLOWED_CORS_ORIGINS += EXTRA_CORS_ALLOWED_ORIGINS.split(",")
 
 
-class ProxyListener(object):
+class ProxyListener:
     # List of `ProxyListener` instances that are enabled by default for all requests.
     # For inbound flows, the default listeners are applied *before* forwarding requests
     # to the backend; for outbound flows, the default listeners are applied *after* the
@@ -343,17 +347,19 @@ class ArnPartitionRewriteListener(MessageModifyingProxyListener):
 # BASE BACKEND UTILS
 # -------------------
 
+T = TypeVar("T", bound="RegionBackend")
 
-class RegionBackend(object):
+
+class RegionBackend:
     """Base class for region-specific backends for the different APIs.
     RegionBackend lookup methods are not thread safe."""
 
-    REGIONS: Dict[str, "RegionBackend"]
+    REGIONS: Dict[str, T]
 
     name: str  # name of the region
 
     @classmethod
-    def get(cls, region: str = None) -> "RegionBackend":
+    def get(cls: Type[T], region: str = None) -> T:
         region = region or cls.get_current_request_region()
 
         regions = cls.regions()
@@ -366,7 +372,7 @@ class RegionBackend(object):
         return regions[region]
 
     @classmethod
-    def regions(cls) -> Dict[str, "RegionBackend"]:
+    def regions(cls: Type[T]) -> Dict[str, T]:
         if not hasattr(cls, "REGIONS"):
             # maps region name to region backend instance
             cls.REGIONS = {}
@@ -465,12 +471,11 @@ def should_enforce_self_managed_service(method, path, headers, data):
     if config.DISABLE_CUSTOM_CORS_S3 and config.DISABLE_CUSTOM_CORS_APIGATEWAY:
         return True
     # allow only certain api calls without checking origin
-    import localstack.services.edge
+    from localstack.aws.protocol.service_router import determine_aws_service_name
+    from localstack.http.adapters import create_request_from_parts
 
-    api, _ = localstack.services.edge.get_api_from_custom_rules(method, path, data, headers) or (
-        "",
-        None,
-    )
+    request = create_request_from_parts(method, path, data, headers)
+    api = determine_aws_service_name(request)
     if not config.DISABLE_CUSTOM_CORS_S3 and api == "s3":
         return False
     if not config.DISABLE_CUSTOM_CORS_APIGATEWAY and api == "apigateway":
@@ -658,9 +663,10 @@ def modify_and_forward(
 
         # make sure we drop "chunked" transfer encoding from the headers to be forwarded
         headers_to_send.pop("Transfer-Encoding", None)
+
         response = requests.request(
             method_to_send,
-            request_url,
+            url=request_url,
             data=data_to_send,
             headers=headers_to_send,
             stream=True,
@@ -669,9 +675,8 @@ def modify_and_forward(
 
     # prevent requests from processing response body (e.g., to pass-through gzip encoded content
     # unmodified)
-    pass_raw = (
-        hasattr(response, "_content_consumed") and not response._content_consumed
-    ) or response.headers.get("content-encoding") in ["gzip"]
+    not_consumed = not getattr(response, "_content_consumed", True)
+    pass_raw = not_consumed or response.headers.get("content-encoding") in ["gzip"]
     if pass_raw and getattr(response, "raw", None):
         new_content = response.raw.read()
         if new_content:
@@ -764,7 +769,7 @@ class DuplexSocket(ssl.SSLSocket):
 ssl.SSLContext.sslsocket_class = DuplexSocket
 
 
-class GenericProxy(object):
+class GenericProxy:
     # TODO: move methods to different class?
     @classmethod
     def create_ssl_cert(cls, serial_number=None):
@@ -935,7 +940,7 @@ def get_cert_pem_file_path():
 
 def start_proxy_server(
     port,
-    bind_address=None,
+    bind_address: Union[str, List[str]] = None,
     forward_url=None,
     use_ssl=None,
     update_listener: Optional[Union[ProxyListener, List[ProxyListener]]] = None,
@@ -946,7 +951,10 @@ def start_proxy_server(
     max_content_length: int = None,
     send_timeout: int = None,
 ):
-    bind_address = bind_address if bind_address else BIND_HOST
+    if bind_address:
+        bind_addresses = bind_address if isinstance(bind_address, List) else [bind_address]
+    else:
+        bind_addresses = [BIND_HOST]
 
     if update_listener is None:
         listeners = []
@@ -957,12 +965,12 @@ def start_proxy_server(
 
     def handler(request, data):
         parsed_url = urlparse(request.url)
-        path_with_params = path_from_url(request.url)
+        path_with_params = request.full_path.strip("?")
         method = request.method
         headers = request.headers
         headers[HEADER_LOCALSTACK_REQUEST_URL] = str(request.url)
-
-        response = modify_and_forward(
+        headers[HEADER_LOCALSTACK_AUTHORIZATION] = headers.get("Authorization", "")
+        return modify_and_forward(
             method=method,
             path=path_with_params,
             data_bytes=data,
@@ -973,8 +981,6 @@ def start_proxy_server(
             server_address=parsed_url.netloc,
         )
 
-        return response
-
     ssl_creds = (None, None)
     if use_ssl:
         install_predefined_cert_if_available()
@@ -983,7 +989,7 @@ def start_proxy_server(
 
     result = http2_server.run_server(
         port,
-        bind_address,
+        bind_addresses=bind_addresses,
         handler=handler,
         asynchronous=asynchronous,
         ssl_creds=ssl_creds,
