@@ -1,4 +1,5 @@
 import json
+import logging
 import re
 from typing import Dict
 from urllib.parse import urlencode
@@ -10,9 +11,12 @@ from requests.models import Request, Response
 
 from localstack import config, constants
 from localstack.config import SQS_PORT_EXTERNAL
-from localstack.services.awslambda.lambda_api import EventSourceListener
+from localstack.services.awslambda.event_source_listeners.event_source_listener import (
+    EventSourceListener,
+)
 from localstack.services.install import SQS_BACKEND_IMPL
 from localstack.services.sns import sns_listener
+from localstack.services.sqs.sqs_utils import is_sqs_queue_url
 from localstack.utils.analytics import event_publisher
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.aws_responses import (
@@ -26,11 +30,12 @@ from localstack.utils.common import (
     ensure_list,
     get_service_protocol,
     parse_request_data,
-    path_from_url,
     to_str,
 )
 from localstack.utils.persistence import PersistingProxyListener
 
+LOG = logging.getLogger(__name__)
+
 API_VERSION = "2012-11-05"
 XMLNS_SQS = "http://queue.amazonaws.com/doc/%s/" % API_VERSION
 
@@ -276,11 +281,6 @@ def validate_empty_message_batch(data, req_data):
     return False
 
 
-def is_sqs_queue_url(url):
-    path = path_from_url(url).partition("?")[0]
-    return re.match(r"^/(queue|%s)/[a-zA-Z0-9_-]+$" % constants.TEST_AWS_ACCOUNT_ID, path)
-
-
 class ProxyListenerSQS(PersistingProxyListener):
     def api_name(self):
         return "sqs"
@@ -332,6 +332,21 @@ class ProxyListenerSQS(PersistingProxyListener):
 
             elif action == "CreateQueue":
                 req_data = self.fix_missing_tag_values(req_data)
+
+                def _is_fifo():
+                    for k, v in req_data.items():
+                        if v == "FifoQueue":
+                            return req_data[k.replace("Name", "Value")].lower() == "true"
+                    return False
+
+                if req_data.get("QueueName").endswith(".fifo") and not _is_fifo():
+                    LOG.warn(
+                        'You are trying to create a queue ending in ".fifo".  Please use the --attributes parameter to set FifoQueue appropriately.'
+                    )
+                    msg = "Can only include alphanumeric characters, hyphens, or underscores. 1 to 80 in length"
+                    return make_requests_error(
+                        code=400, code_string="InvalidParameterValue", message=msg
+                    )
                 changed_attrs = _fix_dlq_arn_in_attributes(req_data)
                 if changed_attrs:
                     return _get_attributes_forward_request(
